@@ -3,7 +3,6 @@ import contextlib
 import logging
 import re
 import traceback
-import uuid
 
 try:
 	import asyncpg
@@ -11,14 +10,16 @@ except ImportError:
 	HAVE_ASYNCPG = False
 else:
 	HAVE_ASYNCPG = True
+
 import discord
 from discord.ext import commands
+
 try:
 	import uvloop
 except ImportError:
 	pass  # Windows
 else:
-	asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
+	uvloop.install()
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger('bot')
@@ -30,7 +31,6 @@ class Bot(commands.AutoShardedBot):
 		if self._should_setup_db and not HAVE_ASYNCPG:
 			raise ImportError('this bot requires asyncpg but it is not installed')
 		self.process_config()
-		self._fallback_prefix = str(uuid.uuid4())
 
 		super().__init__(
 			command_prefix=self.get_prefix_,
@@ -74,26 +74,35 @@ class Bot(commands.AutoShardedBot):
 			# Callable prefixes must always return at least one prefix,
 			# but no prefix was found in the message,
 			# so we still have to return *something*.
-			# Use a UUID because it's practically guaranteed not to be in the message.
-			return self._fallback_prefix
+			# Messages are guaranteed not to start with a space.
+			return ' '
 		else:
 			return match[0]
 
 	@property
 	def prefix_re(self):
+		with contextlib.suppress(AttributeError):
+			return self._prefix_re
+
 		prefixes = self.config.get('prefixes', [])
 
 		prefixes = list(prefixes)  # ensure it's not a tuple
+		have_client_user = False
 		try:
 			prefixes.extend([f'<@{self.user.id}>', f'<@!{self.user.id}>'])
 		except AttributeError:
 			if not prefixes:
 				return None
+		else:
+			have_client_user = True
 
 		prefixes = '|'.join(map(re.escape, prefixes))
 		prefixes = f'(?:{prefixes})'
 
-		return re.compile(fr'{prefixes}\s*', re.IGNORECASE)
+		regex = re.compile(fr'{prefixes}\s*', re.IGNORECASE)
+		if have_client_user:
+			self._prefix_re = regex
+		return regex
 
 	### Events
 
